@@ -3,9 +3,10 @@ from Supplychain.Wrappers.simulator import CosmoEngine
 
 
 def run_simple_simulation(simulation_name: str,
+                          simulation_path: str = 'Simulation',
                           amqp_consumer_adress: Union[str, None] = None,
                           modifications: Union[dict, None] = None) -> bool:
-    simulator = CosmoEngine.LoadSimulator('Simulation')
+    simulator = CosmoEngine.LoadSimulator(simulation_path)
 
     if modifications:
         for datapath, stringvalue in modifications.items():
