@@ -83,6 +83,7 @@ class ValidationSchemas:
                     ],
                 },
                 "FinancialCostOfStock": {"type": "number", "minimum": 0, "maximum": 1},
+                "CarbonTax": {"type": "number", "minimum": 0},
                 "BatchSize": {"type": "integer", "minimum": 0},
                 "EmptyObsoleteStocks": {"type": "boolean"},
                 "ActivateVariableMachineOpeningRate": {"type": "boolean"},
@@ -94,6 +95,66 @@ class ValidationSchemas:
                 "ActualizeShipments": {"type": "boolean"},
                 "ActivateCorrelatedDemandUncertainties": {"type": "boolean"},
                 "DemandCorrelations": {"type": "number", "minimum": 0, "maximum": 1},
+                "Kpi": {
+                    "type": "string",
+                    "enum": [
+                        "Profit",
+                        "OPEX",
+                        "AverageStockValue",
+                        "ServiceLevelIndicator",
+                        "ServiceLevelSatisfaction",
+                        "CO2Emissions",
+                        "TotalServedQuantity",
+                        "IndividualServiceLevelSatisfaction",
+                    ],
+                },
+                "OptimizationMode": {
+                    "type": "string",
+                    "enum": [
+                        "maximize",
+                        "minimize",
+                        "target",
+                    ],
+                },
+                "Statistic": {
+                    "type": "string",
+                    "enum": [
+                        "mean",
+                        "std",
+                        "sem",
+                        "quantile 5%",
+                        "quantile 10%",
+                        "quantile 15%",
+                        "quantile 20%",
+                        "quantile 25%",
+                        "quantile 30%",
+                        "quantile 35%",
+                        "quantile 40%",
+                        "quantile 45%",
+                        "quantile 50%",
+                        "quantile 55%",
+                        "quantile 60%",
+                        "quantile 65%",
+                        "quantile 70%",
+                        "quantile 75%",
+                        "quantile 80%",
+                        "quantile 85%",
+                        "quantile 90%",
+                        "quantile 95%",
+                    ],
+                },
+                "TargetedValue": {"type": "number"},
+                "DecisionVariable": {"type": "string"},
+                "DecisionVariableMin": {"type": "number"},
+                "DecisionVariableMax": {"type": "number"},
+                "OptimizationMaximalDuration": {"type": "number"},
+                "OptimizationAlgorithm": {"type": "string"},
+                "OptimizationBatchSize": {"type": "integer", "minimum": 1},
+                "SampleSizeUncertaintyAnalysis": {"type": "integer"},
+                "FinalSampleSizeUncertaintyAnalysis": {"type": "integer"},
+                "MaxIterationsForOptim": {"type": "integer"},
+                "AutomaticParallelizationConfig": {"type": "boolean"},
+                "MaxNumberOfSimInParallel": {"type": "integer", "minimum": 1},
             },
         },
         "input": {
@@ -121,7 +182,9 @@ class ValidationSchemas:
                 },
                 "CycleTimes": {
                     "type": "object",
-                    "patternProperties": {"^[0-9]+$": {"type": "number", "minimum": 0}},
+                    "patternProperties": {
+                        "^[0-9]+$": {"type": "number", "exclusiveMinimum": 0}
+                    },
                     "if": {"minProperties": 1},
                     "then": {"required": ["0"]},
                 },
@@ -167,7 +230,9 @@ class ValidationSchemas:
                 },
                 "SourcingProportions": {
                     "type": "object",
-                    "patternProperties": {"^[0-9]+$": {"type": "number", "minimum": 0, "maximum": 1}},
+                    "patternProperties": {
+                        "^[0-9]+$": {"type": "number", "minimum": 0, "maximum": 1}
+                    },
                     "if": {"minProperties": 1},
                     "then": {"required": ["0"]},
                 },
@@ -281,6 +346,7 @@ class ValidationSchemas:
                         "OrderPointFixedQuantity",
                         "OrderPointVariableQuantity",
                         "MakeToForecast",
+                        "MakeToOrder",
                     ],
                 },
                 "SourcingPolicy": {
@@ -335,6 +401,7 @@ class ValidationSchemas:
                 },
                 "Latitude": {"type": "number", "minimum": -90, "maximum": 90},
                 "Longitude": {"type": "number", "minimum": -180, "maximum": 180},
+                "IgnoreDownstreamRequiredQuantities": {"type": "boolean"},
             },
             "dependencies": {"InitialValue": ["InitialStock"]},
         },
@@ -393,7 +460,9 @@ class ValidationSchemas:
                 },
                 "SourcingProportions": {
                     "type": "object",
-                    "patternProperties": {"^[0-9]+$": {"type": "number", "minimum": 0, "maximum": 1}},
+                    "patternProperties": {
+                        "^[0-9]+$": {"type": "number", "minimum": 0, "maximum": 1}
+                    },
                     "if": {"minProperties": 1},
                     "then": {"required": ["0"]},
                 },
