@@ -339,7 +339,7 @@ class DictValidator(Timer):
                 has_demands = any(stock_demands.values())
                 stock_policy = stock.get('StockPolicy')
                 if stock_policy is None:
-                    stock_policy = parameters_default_values['Configuration']['StockPolicy']
+                    stock_policy = parameters_default_values['Stock']['StockPolicy']
                 has_stock_policy = stock_policy != 'None'
                 if has_demands and has_stock_policy:
                     self.errors.append(('Configuration',
